# Core Developers
----------
- [@sepandhaghighi](http://github.com/sepandhaghighi)
- [@sadrasabouri](https://github.com/sadrasabouri)


# Other Contributors
----------
- [@sarahfard](https://github.com/sarahfard) **
- [@oscarArismendi](https://github.com/oscarArismendi)
- [@AHReccese](https://github.com/AHReccese)


** Graphic designer

